#ifndef NT2_INCLUDE_FUNCTIONS_ORTH_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_ORTH_HPP_INCLUDED

#include <nt2/linalg/include/functions/orth.hpp>

#endif
